@@ -56,7 +56,7 @@ class Message(object):
     >>> m.payload_json()
     '{"moo": "cow"}'
     """
-    def __init__(self, obj, secret, expected_hash=None):
+    def __init__(self, obj, secret, expected_hash=None, iterations=1000):
         """
         The constructor for the Message object.
 
@@ -72,6 +72,7 @@ class Message(object):
         self.obj = obj.copy()
         self.secret = secret
         self.expected_hash = expected_hash
+        self.iterations = iterations
 
     def payload_json(self):
         """
@@ -93,7 +94,7 @@ class Message(object):
         >>> m.signature()
         'b617fdca6b994fa3cb45ea744e3b66f6daee37e24cd1e6df50a6ff38094549a412498c5830144000d3ed451efd39934a6cdc495cb0c86c892f66162a944e6025'
         """
-        signature = pbkdf2_hex(self.payload_json(), self.secret, iterations=1000, keylen=64, hashfunc=hashlib.sha512)
+        signature = pbkdf2_hex(self.payload_json(), self.secret, iterations=self.iterations, keylen=64, hashfunc=hashlib.sha512)
         return signature
 
     def dumps(self, pretty_print=False):
@@ -148,7 +149,7 @@ class Message(object):
 class InvalidSignatureException(Exception):
     pass
 
-def loads(json_data, secret, allow_unsigned=False):
+def loads(json_data, secret, allow_unsigned=False, iterations=1000):
     """
     Unpack a JSON envelope containing an Edia RPC message.
 
@@ -175,13 +176,13 @@ def loads(json_data, secret, allow_unsigned=False):
     if signature is None and allow_unsigned is not True:
         raise InvalidSignatureException()
 
-    message = Message(envelope, secret, signature)
+    message = Message(envelope, secret, signature, iterations)
     if message.validate() is not True and allow_unsigned is not True:
         raise InvalidSignatureException()
 
     return message.payload()
 
-def dumps(obj, secret, pretty_print=False):
+def dumps(obj, secret, pretty_print=False, iterations=1000):
     """
     Pack a dictionary into an Edia RPC message.
 
@@ -198,7 +199,7 @@ def dumps(obj, secret, pretty_print=False):
     >>> signed_message == dumps(unpack_message, secret)
     True
     """
-    return Message(obj, secret).dumps(pretty_print)
+    return Message(obj, secret, iterations=iterations).dumps(pretty_print)
 
 if __name__ == '__main__':
     import doctest
