@@ -22,7 +22,7 @@ class RPCRequestHandler(SocketServer.StreamRequestHandler):
             line = self.rfile.readline()
             if not line:
                 break
-            response = self.server.dispatch(line)
+            response = self.server.dispatch(line) + '\r\n'
             self.wfile.write(response)
 
 class RPCServer(SocketServer.TCPServer, RPCRequestHandler):
